@@ -1,5 +1,5 @@
 """
-The PythonInfo contains information about a concrete instance of a Python interpreter
+The PythonInfo contains information about a concrete instance of a Python interpreter.
 
 Note: this file is also used to query target interpreters, so can only use standard library methods
 """
@@ -21,7 +21,7 @@ VersionInfo = namedtuple("VersionInfo", ["major", "minor", "micro", "releaseleve
 
 
 def _get_path_extensions():
-    return list(OrderedDict.fromkeys([""] + os.environ.get("PATHEXT", "").lower().split(os.pathsep)))
+    return list(OrderedDict.fromkeys(["", *os.environ.get("PATHEXT", "").lower().split(os.pathsep)]))
 
 
 EXTENSIONS = _get_path_extensions()
@@ -29,9 +29,9 @@ _CONF_VAR_RE = re.compile(r"\{\w+\}")
 
 
 class PythonInfo:
-    """Contains information for a Python interpreter"""
+    """Contains information for a Python interpreter."""
 
-    def __init__(self):
+    def __init__(self) -> None:  # noqa: PLR0915
         def abs_path(v):
             return None if v is None else os.path.abspath(v)  # unroll relative elements from path (e.g. ..)
 
@@ -128,13 +128,13 @@ class PythonInfo:
         self._creators = None
 
     def _fast_get_system_executable(self):
-        """Try to get the system executable by just looking at properties"""
+        """Try to get the system executable by just looking at properties."""
         if self.real_prefix or (
             self.base_prefix is not None and self.base_prefix != self.prefix
         ):  # if this is a virtual environment
             if self.real_prefix is None:
                 base_executable = getattr(sys, "_base_executable", None)  # some platforms may set this to help us
-                if base_executable is not None:  # use the saved system executable if present
+                if base_executable is not None:  # noqa: SIM102 # use the saved system executable if present
                     if sys.executable != base_executable:  # we know we're in a virtual environment, cannot be us
                         if os.path.exists(base_executable):
                             return base_executable
@@ -182,7 +182,7 @@ class PythonInfo:
 
         d = dist.Distribution({"script_args": "--no-user-cfg"})  # conf files not parsed so they do not hijack paths
         if hasattr(sys, "_framework"):
-            sys._framework = None  # disable macOS static paths for framework
+            sys._framework = None  # disable macOS static paths for framework  # noqa: SLF001
 
         with warnings.catch_warnings():  # disable warning for PEP-632
             warnings.simplefilter("ignore")
@@ -190,8 +190,7 @@ class PythonInfo:
 
         i.prefix = os.sep  # paths generated are relative to prefix that contains the path sep, this makes it relative
         i.finalize_options()
-        result = {key: (getattr(i, f"install_{key}")[1:]).lstrip(os.sep) for key in SCHEME_KEYS}
-        return result
+        return {key: (getattr(i, f"install_{key}")[1:]).lstrip(os.sep) for key in SCHEME_KEYS}
 
     @property
     def version_str(self):
@@ -224,7 +223,7 @@ class PythonInfo:
             config_var = base
         return pattern.format(**config_var).replace("/", sep)
 
-    def creators(self, refresh=False):
+    def creators(self, refresh=False):  # noqa: FBT002
         if self._creators is None or refresh is True:
             from virtualenv.run.plugin.creators import CreatorSelector
 
@@ -256,17 +255,16 @@ class PythonInfo:
         return self.real_prefix or self.base_exec_prefix or self.exec_prefix
 
     def __unicode__(self):
-        content = repr(self)
-        return content
+        return repr(self)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return "{}({!r})".format(
             self.__class__.__name__,
             {k: v for k, v in self.__dict__.items() if not k.startswith("_")},
         )
 
-    def __str__(self):
-        content = "{}({})".format(
+    def __str__(self) -> str:
+        return "{}({})".format(
             self.__class__.__name__,
             ", ".join(
                 f"{k}={v}"
@@ -295,7 +293,6 @@ class PythonInfo:
                 if k is not None
             ),
         )
-        return content
 
     @property
     def spec(self):
@@ -309,8 +306,8 @@ class PythonInfo:
         clear(app_data)
         cls._cache_exe_discovery.clear()
 
-    def satisfies(self, spec, impl_must_match):
-        """check if a given specification can be satisfied by the this python interpreter instance"""
+    def satisfies(self, spec, impl_must_match):  # noqa: C901
+        """Check if a given specification can be satisfied by the this python interpreter instance."""
         if spec.path:
             if self.executable == os.path.abspath(spec.path):
                 return True  # if the path is a our own executable path we're done
@@ -325,9 +322,12 @@ class PythonInfo:
                 if basename != spec_path:
                     return False
 
-        if impl_must_match:
-            if spec.implementation is not None and spec.implementation.lower() != self.implementation.lower():
-                return False
+        if (
+            impl_must_match
+            and spec.implementation is not None
+            and spec.implementation.lower() != self.implementation.lower()
+        ):
+            return False
 
         if spec.architecture is not None and spec.architecture != self.architecture:
             return False
@@ -345,7 +345,7 @@ class PythonInfo:
         """
         This locates the current host interpreter information. This might be different than what we run into in case
         the host python has been upgraded from underneath us.
-        """
+        """  # noqa: D205
         if cls._current is None:
             cls._current = cls.from_exe(sys.executable, app_data, raise_on_error=True, resolve_to_host=False)
         return cls._current
@@ -355,7 +355,7 @@ class PythonInfo:
         """
         This locates the current host interpreter information. This might be different than what we run into in case
         the host python has been upgraded from underneath us.
-        """
+        """  # noqa: D205
         if cls._current_system is None:
             cls._current_system = cls.from_exe(sys.executable, app_data, raise_on_error=True, resolve_to_host=True)
         return cls._current_system
@@ -366,25 +366,33 @@ class PythonInfo:
 
     def _to_dict(self):
         data = {var: (getattr(self, var) if var not in ("_creators",) else None) for var in vars(self)}
-        # noinspection PyProtectedMember
+
         data["version_info"] = data["version_info"]._asdict()  # namedtuple to dictionary
         return data
 
     @classmethod
-    def from_exe(cls, exe, app_data=None, raise_on_error=True, ignore_cache=False, resolve_to_host=True, env=None):
-        """Given a path to an executable get the python information"""
+    def from_exe(  # noqa: PLR0913
+        cls,
+        exe,
+        app_data=None,
+        raise_on_error=True,  # noqa: FBT002
+        ignore_cache=False,  # noqa: FBT002
+        resolve_to_host=True,  # noqa: FBT002
+        env=None,
+    ):
+        """Given a path to an executable get the python information."""
         # this method is not used by itself, so here and called functions can import stuff locally
         from virtualenv.discovery.cached_py_info import from_exe
 
         env = os.environ if env is None else env
         proposed = from_exe(cls, app_data, exe, env=env, raise_on_error=raise_on_error, ignore_cache=ignore_cache)
-        # noinspection PyProtectedMember
+
         if isinstance(proposed, PythonInfo) and resolve_to_host:
             try:
-                proposed = proposed._resolve_to_system(app_data, proposed)
-            except Exception as exception:
+                proposed = proposed._resolve_to_system(app_data, proposed)  # noqa: SLF001
+            except Exception as exception:  # noqa: BLE001
                 if raise_on_error:
-                    raise exception
+                    raise
                 logging.info("ignore %s due cannot resolve system due to %r", proposed.original_executable, exception)
                 proposed = None
         return proposed
@@ -417,7 +425,8 @@ class PythonInfo:
                 for at, (p, t) in enumerate(prefixes.items(), start=1):
                     logging.error("%d: prefix=%s, info=%r", at, p, t)
                 logging.error("%d: prefix=%s, info=%r", len(prefixes) + 1, prefix, target)
-                raise RuntimeError("prefixes are causing a circle {}".format("|".join(prefixes.keys())))
+                msg = "prefixes are causing a circle {}".format("|".join(prefixes.keys()))
+                raise RuntimeError(msg)
             prefixes[prefix] = target
             target = target.discover_exe(app_data, prefix=prefix, exact=False)
         if target.executable != target.system_executable:
@@ -427,7 +436,7 @@ class PythonInfo:
 
     _cache_exe_discovery = {}
 
-    def discover_exe(self, app_data, prefix, exact=True, env=None):
+    def discover_exe(self, app_data, prefix, exact=True, env=None):  # noqa: FBT002
         key = prefix, exact
         if key in self._cache_exe_discovery and prefix:
             logging.debug("discover exe from cache %s - exact %s: %r", prefix, exact, self._cache_exe_discovery[key])
@@ -453,7 +462,7 @@ class PythonInfo:
         msg = "failed to detect {} in {}".format("|".join(possible_names), os.pathsep.join(possible_folders))
         raise RuntimeError(msg)
 
-    def _check_exe(self, app_data, folder, name, exact, discovered, env):
+    def _check_exe(self, app_data, folder, name, exact, discovered, env):  # noqa: PLR0913
         exe_path = os.path.join(folder, name)
         if not os.path.exists(exe_path):
             return None
@@ -491,12 +500,10 @@ class PythonInfo:
                 info.version_info.releaselevel == target.version_info.releaselevel,
                 info.version_info.serial == target.version_info.serial,
             ]
-            priority = sum((1 << pos if match else 0) for pos, match in enumerate(reversed(matches)))
-            return priority
+            return sum((1 << pos if match else 0) for pos, match in enumerate(reversed(matches)))
 
         sorted_discovered = sorted(discovered, key=sort_by, reverse=True)  # sort by priority in decreasing order
-        most_likely = sorted_discovered[0]
-        return most_likely
+        return sorted_discovered[0]
 
     def _find_possible_folders(self, inside_folder):
         candidate_folder = OrderedDict()
@@ -505,7 +512,7 @@ class PythonInfo:
         executables[self.executable] = None
         executables[os.path.realpath(self.original_executable)] = None
         executables[self.original_executable] = None
-        for exe in executables.keys():
+        for exe in executables:
             base = os.path.dirname(exe)
             # following path pattern of the current
             if base.startswith(self.prefix):
@@ -514,7 +521,7 @@ class PythonInfo:
 
         # or at root level
         candidate_folder[inside_folder] = None
-        return [i for i in candidate_folder.keys() if os.path.exists(i)]
+        return [i for i in candidate_folder if os.path.exists(i)]
 
     def _find_possible_exe_names(self):
         name_candidate = OrderedDict()
@@ -551,7 +558,7 @@ class PythonInfo:
 
 if __name__ == "__main__":
     # dump a JSON representation of the current python
-    # noinspection PyProtectedMember
+
     argv = sys.argv[1:]
 
     if len(argv) >= 1:
@@ -568,5 +575,5 @@ if __name__ == "__main__":
 
     sys.argv = sys.argv[:1] + argv
 
-    info = PythonInfo()._to_json()
+    info = PythonInfo()._to_json()  # noqa: SLF001
     sys.stdout.write("".join((start_cookie[::-1], info, end_cookie[::-1])))
