@@ -1,4 +1,4 @@
-"""Implement https://www.python.org/dev/peps/pep-0514/ to discover interpreters - Windows only"""
+"""Implement https://www.python.org/dev/peps/pep-0514/ to discover interpreters - Windows only."""
 
 from __future__ import annotations
 
@@ -66,26 +66,27 @@ def process_tag(hive_name, company, company_key, tag, default_arch):
                 if exe_data is not None:
                     exe, args = exe_data
                     return company, major, minor, arch, exe, args
+                return None
+            return None
+        return None
 
 
 def load_exe(hive_name, company, company_key, tag):
     key_path = f"{hive_name}/{company}/{tag}"
     try:
-        with winreg.OpenKeyEx(company_key, rf"{tag}\InstallPath") as ip_key:
-            with ip_key:
-                exe = get_value(ip_key, "ExecutablePath")
-                if exe is None:
-                    ip = get_value(ip_key, None)
-                    if ip is None:
-                        msg(key_path, "no ExecutablePath or default for it")
+        with winreg.OpenKeyEx(company_key, rf"{tag}\InstallPath") as ip_key, ip_key:
+            exe = get_value(ip_key, "ExecutablePath")
+            if exe is None:
+                ip = get_value(ip_key, None)
+                if ip is None:
+                    msg(key_path, "no ExecutablePath or default for it")
 
-                    else:
-                        exe = os.path.join(ip, "python.exe")
-                if exe is not None and os.path.exists(exe):
-                    args = get_value(ip_key, "ExecutableArguments")
-                    return exe, args
                 else:
-                    msg(key_path, f"could not load exe with value {exe}")
+                    exe = os.path.join(ip, "python.exe")
+            if exe is not None and os.path.exists(exe):
+                args = get_value(ip_key, "ExecutableArguments")
+                return exe, args
+            msg(key_path, f"could not load exe with value {exe}")
     except OSError:
         msg(f"{key_path}/InstallPath", "missing")
     return None
@@ -109,7 +110,7 @@ def parse_arch(arch_str):
             return int(next(iter(match.groups())))
         error = f"invalid format {arch_str}"
     else:
-        error = f"arch is not string: {repr(arch_str)}"
+        error = f"arch is not string: {arch_str!r}"
     raise ValueError(error)
 
 
@@ -146,7 +147,7 @@ def _run():
     interpreters = []
     for spec in discover_pythons():
         interpreters.append(repr(spec))
-    print("\n".join(sorted(interpreters)))
+    print("\n".join(sorted(interpreters)))  # noqa: T201
 
 
 if __name__ == "__main__":
