@@ -7,33 +7,33 @@ from virtualenv.seed.wheels.util import Wheel
 BUNDLE_FOLDER = Path(__file__).absolute().parent
 BUNDLE_SUPPORT = {
     "3.7": {
-        "pip": "pip-23.1-py3-none-any.whl",
-        "setuptools": "setuptools-67.6.1-py3-none-any.whl",
+        "pip": "pip-23.1.2-py3-none-any.whl",
+        "setuptools": "setuptools-67.8.0-py3-none-any.whl",
         "wheel": "wheel-0.40.0-py3-none-any.whl",
     },
     "3.8": {
-        "pip": "pip-23.1-py3-none-any.whl",
-        "setuptools": "setuptools-67.6.1-py3-none-any.whl",
+        "pip": "pip-23.1.2-py3-none-any.whl",
+        "setuptools": "setuptools-67.8.0-py3-none-any.whl",
         "wheel": "wheel-0.40.0-py3-none-any.whl",
     },
     "3.9": {
-        "pip": "pip-23.1-py3-none-any.whl",
-        "setuptools": "setuptools-67.6.1-py3-none-any.whl",
+        "pip": "pip-23.1.2-py3-none-any.whl",
+        "setuptools": "setuptools-67.8.0-py3-none-any.whl",
         "wheel": "wheel-0.40.0-py3-none-any.whl",
     },
     "3.10": {
-        "pip": "pip-23.1-py3-none-any.whl",
-        "setuptools": "setuptools-67.6.1-py3-none-any.whl",
+        "pip": "pip-23.1.2-py3-none-any.whl",
+        "setuptools": "setuptools-67.8.0-py3-none-any.whl",
         "wheel": "wheel-0.40.0-py3-none-any.whl",
     },
     "3.11": {
-        "pip": "pip-23.1-py3-none-any.whl",
-        "setuptools": "setuptools-67.6.1-py3-none-any.whl",
+        "pip": "pip-23.1.2-py3-none-any.whl",
+        "setuptools": "setuptools-67.8.0-py3-none-any.whl",
         "wheel": "wheel-0.40.0-py3-none-any.whl",
     },
     "3.12": {
-        "pip": "pip-23.1-py3-none-any.whl",
-        "setuptools": "setuptools-67.6.1-py3-none-any.whl",
+        "pip": "pip-23.1.2-py3-none-any.whl",
+        "setuptools": "setuptools-67.8.0-py3-none-any.whl",
         "wheel": "wheel-0.40.0-py3-none-any.whl",
     },
 }
