@@ -8,7 +8,7 @@ from virtualenv.info import IS_WIN
 
 def test_nushell(activation_tester_class, activation_tester):
     class Nushell(activation_tester_class):
-        def __init__(self, session):
+        def __init__(self, session) -> None:
             cmd = which("nu")
             if cmd is None and IS_WIN:
                 cmd = "c:\\program files\\nu\\bin\\nu.exe"
