@@ -23,7 +23,7 @@ CURRENT = PythonInfo.current_system()
 
 
 def test_current_as_json():
-    result = CURRENT._to_json()
+    result = CURRENT._to_json()  # noqa: SLF001
     parsed = json.loads(result)
     a, b, c, d, e = sys.version_info
     assert parsed["version_info"] == {"major": a, "minor": b, "micro": c, "releaselevel": d, "serial": e}
@@ -197,7 +197,15 @@ PyInfoMock = namedtuple("PyInfoMock", ["implementation", "architecture", "versio
         ),
     ],
 )
-def test_system_executable_no_exact_match(target, discovered, position, tmp_path, mocker, caplog, session_app_data):
+def test_system_executable_no_exact_match(  # noqa: PLR0913
+    target,
+    discovered,
+    position,
+    tmp_path,
+    mocker,
+    caplog,
+    session_app_data,
+):
     """Here we should fallback to other compatible"""
     caplog.set_level(logging.DEBUG)
 
@@ -227,8 +235,7 @@ def test_system_executable_no_exact_match(target, discovered, position, tmp_path
     mocker.patch.object(target_py_info, "_find_possible_exe_names", return_value=names)
     mocker.patch.object(target_py_info, "_find_possible_folders", return_value=[str(tmp_path)])
 
-    # noinspection PyUnusedLocal
-    def func(k, app_data, resolve_to_host, raise_on_error, env):  # noqa: U100
+    def func(k, app_data, resolve_to_host, raise_on_error, env):  # noqa: ARG001
         return discovered_with_path[k]
 
     mocker.patch.object(target_py_info, "from_exe", side_effect=func)
@@ -236,7 +243,7 @@ def test_system_executable_no_exact_match(target, discovered, position, tmp_path
 
     target_py_info.system_executable = None
     target_py_info.executable = str(tmp_path)
-    mapped = target_py_info._resolve_to_system(session_app_data, target_py_info)
+    mapped = target_py_info._resolve_to_system(session_app_data, target_py_info)  # noqa: SLF001
     assert mapped.system_executable == CURRENT.system_executable
     found = discovered_with_path[mapped.base_executable]
     assert found is selected
@@ -382,7 +389,7 @@ def test_fallback_existent_system_executable(mocker):
     # that "python" is not required and the standard `make install` does not provide one
 
     # Falsify some data to look like we're in a venv
-    current.prefix = current.exec_prefix = "/tmp/tmp.izZNCyINRj/venv"
+    current.prefix = current.exec_prefix = "/tmp/tmp.izZNCyINRj/venv"  # noqa: S108
     current.executable = current.original_executable = os.path.join(current.prefix, "bin/python")
 
     # Since we don't know if the distribution we're on provides python, use a binary that should not exist
@@ -390,7 +397,7 @@ def test_fallback_existent_system_executable(mocker):
     mocker.patch.object(sys, "executable", current.executable)
 
     # ensure it falls back to an alternate binary name that exists
-    current._fast_get_system_executable()
+    current._fast_get_system_executable()  # noqa: SLF001
     assert os.path.basename(current.system_executable) in [
         f"python{v}" for v in (current.version_info.major, f"{current.version_info.major}.{current.version_info.minor}")
     ]
